# EasyPaint

Biblioteca de dibujo para Python 3.

Requiere que la biblioteca *tkinter* esté instalada:
- En MS Windows se incluye con la instalación de Python.
- En Ubuntu hay que instalar el paquete *python3-tk*.
